<template>
    <div class="dialog">
        <div class="dialog-breadcrumb">
            <el-breadcrumb separator="/">
                <el-breadcrumb-item :to="{path: '/platLayout/chargeData'}">
                    <i class="el-icon-s-finance"></i><span>收费数据</span>
                </el-breadcrumb-item>
                <el-breadcrumb-item
                    ><span>收费数据详情</span></el-breadcrumb-item
                >
            </el-breadcrumb>
        </div>
        <div class="dialog-details">
            <el-descriptions
                :column="3"
                border
                v-loading="loading"
                :labelStyle="{width: '8%'}"
            >
                <template slot="title">
                    <div class="details-title-content">
                        <span class="details-title">收费数据详情</span>
                    </div>
                </template>
                <template slot="extra">
                    <el-button
                        @click="handleEdit"
                        size="mini"
                        icon="el-icon-edit"
                        round
                        type="primary"
                        v-methodauth="'saveCharge'"
                        >编辑</el-button
                    >
                    <el-button
                        @click="getDataById"
                        size="mini"
                        icon="el-icon-refresh"
                        round
                        type="primary"
                        plain
                        >刷新</el-button
                    >
                </template>
                <el-descriptions-item label="所属路段">
                    {{ dialogForm.roadName || '暂无' }}
                </el-descriptions-item>
                <el-descriptions-item label="收费站">
                    {{ dialogForm.tollStationName || '暂无' }}
                </el-descriptions-item>
                <el-descriptions-item label="车道">
                    {{ dialogForm.laneName || '暂无' }}
                </el-descriptions-item>
                <el-descriptions-item label="进站时间">
                    {{ dialogForm.startTime ? dialogForm.startTime : '暂无' }}
                </el-descriptions-item>
                <el-descriptions-item label="出站时间">
                    {{ dialogForm.endTime ? dialogForm.endTime : '暂无' }}
                </el-descriptions-item>
                <el-descriptions-item label="通行时长">
                    <el-tag v-if="dialogForm.passTime">
                        {{
                            dialogForm.hh +
                            ':' +
                            dialogForm.mm +
                            ':' +
                            dialogForm.ss
                        }}</el-tag
                    >
                    <!-- <span v-if="dialogForm.passTime">
                        {{
                            dialogForm.hh +
                            ':' +
                            dialogForm.mm +
                            ':' +
                            dialogForm.ss
                        }}
                    </span> -->
                    <span v-else>暂无</span>
                </el-descriptions-item>
                <el-descriptions-item label="车牌">
                    {{ dialogForm.carNo || '暂无' }}
                </el-descriptions-item>
                <el-descriptions-item label="车辆类型" :span="2">
                    {{ getDictName('cllx', dialogForm.carType) }}
                </el-descriptions-item>
                <el-descriptions-item label="收费方式">
                    <el-tag type="success" v-if="dialogForm.isEtc == 1"
                        >ETC</el-tag
                    >
                    <el-tag v-else-if="dialogForm.isEtc == 0"> 非ETC </el-tag>
                    <el-tag v-else> 暂无 </el-tag>
                </el-descriptions-item>
                <el-descriptions-item label="支付方式" :span="2">
                    <el-tag type="success" v-if="dialogForm.isCash == 1"
                        >现金</el-tag
                    >
                    <el-tag v-else-if="dialogForm.isCash == 0"> 非现金 </el-tag>
                    <el-tag v-else> 暂无 </el-tag>
                </el-descriptions-item>
                <el-descriptions-item label="应缴金额">
                    {{ dialogForm.payableMoney + '元' || '暂无' }}
                </el-descriptions-item>
                <el-descriptions-item label="实缴金额">
                    {{ dialogForm.actualityMoney + '元' || '暂无' }}
                </el-descriptions-item>
                <el-descriptions-item label="减免金额">
                    {{ dialogForm.reductionMoney + '元' || '暂无' }}
                </el-descriptions-item>
                <el-descriptions-item label="减免原因" :span="3">
                    {{ dialogForm.reductionReason || '暂无' }}
                </el-descriptions-item>
            </el-descriptions>
        </div>
    </div>
</template>


<script>
import chargeData from '@/api/DataManagement/chargeData.js'
import routerManagement from '@/api/BasicDataManagement/tollStationManagement.js'
import companyInfoSelector from '../../components/companyInfoSelector.vue'
import utils from '@/utils.js'
export default {
    name: 'detailCharge',
    components: {
        companyInfoSelector,
    },
    data() {
        return {
            id: '',
            edit: false,
            loading: false,
            dialogForm: {
                payableMoney: 0,
                actualityMoney: 0,
                reductionMoney: 0,
                hh: 0,
                mm: 0,
                ss: 0,
                isEtc: 1,
                isCash: 0,
                carType: 1,
            },
            roadOptions: [], // 路段数据
            tollStationOptions: [], // 收费站数据
            rules: {},
        }
    },
    mounted() {
        this.id = this.$route.query.id
        if (this.id) {
            this.getDataById()
        }
    },
    methods: {
        // 获取字典值翻译
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        getDataById() {
            this.loading = true
            chargeData.getDataById(this.id).then((res) => {
                this.dialogForm = res
                this.formatPassTime()
                this.formatTimeRange()
                this.loading = false
            })
        },
        formatTimeRange() {
            this.dialogForm.range = [
                this.dialogForm.startTime,
                this.dialogForm.endTime,
            ]
        },
        formatPassTime() {
            function addZero(n) {
                let temp
                n < 10 ? (temp = '0' + n) : (temp = n)
                return temp
            }
            let totalseconds = this.dialogForm.passTime // 时长 以秒为单位
            this.dialogForm.ss = addZero(totalseconds % 60) // 取余得秒
            let hh = 0 //小时 默认0
            let mm = Math.floor(totalseconds / 60) //除以60取整数，得到整数分钟

            // 如果分钟大于60，将分钟转换成小时
            if (mm > 60) {
                // 获取小时整数
                hh = Math.floor(mm / 60)

                // 取余的分钟数
                mm = mm % 60
            }
            this.dialogForm.mm = addZero(mm)
            this.dialogForm.hh = addZero(hh)
        },
        handleEdit() {
            this.$router.push({
                path: '/platLayout/editCharge',
                query: {id: this.id},
            })
        },
    },
}
</script>
<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';

.el-icon-s-finance{
    color: $--color-primary;
    font-size: 18px !important;
    margin-right: 6px;
    margin-top:-2px;
}

/deep/ .el-descriptions{
    margin-top: 0!important;
}

</style>